Calculate network distances to nearest 'n' points.
Arguments
- graph
A
dodgrnetwork returned from the weight_streetnet function using a network obtained with the osmdataosmdata_scfunction.- from
Vector of OpenStreetMap ID values from which route distances are to be calculated.
- to
Vector of OpenStreetMap ID values to which nearest 'npts' distances are to be calculated.
- npts
Number of points to which distances are to be calculated.