Uses a default cache location specified by rappdirs::user_cache_dir(). This
location can be over-ridden by specifying a local environment variable,
"M4RA_CACHE_DIR". The "city" parameter is only used as a prefix for the
cached networks.
Value
A character vector of local locations of cached versions of the variously weighted network representations used in the various routing functions.